@@ -1,7 +1,7 @@
 package App::ZodiacUtils;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-12-18'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -123,7 +123,7 @@ App::ZodiacUtils - CLI utilities related to zodiac
 
 =head1 VERSION
 
-This document describes version 0.05 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-12-17.
+This document describes version 0.06 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-12-18.
 
 =head1 DESCRIPTION
 
@@ -140,7 +140,7 @@ This distribution includes the following CLI utilities:
 =head1 FUNCTIONS
 
 
-=head2 chinese_zodiac_of(%args) -> [status, msg, result, meta]
+=head2 chinese_zodiac_of(%args) -> any
 
 Show Chinese zodiac for a date.
 
@@ -171,19 +171,10 @@ Dates.
 
 =back
 
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
 Return value:  (any)
 
 
-=head2 zodiac_of(%args) -> [status, msg, result, meta]
+=head2 zodiac_of(%args) -> any
 
 Show zodiac for a date.
 
@@ -211,15 +202,6 @@ Dates.
 
 =back
 
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
 Return value:  (any)
 
 =head1 SEE ALSO
